@@ -35,14 +35,3 @@ class HttpPool(LocalPool):
         """
         # print(__name__ + str(kwds))
         super(HttpPool, self).__init__(**kwds)
-
-    def xschematicLoadProduct(self, resourcetype, index, serialized=True):
-        """
-        like localpool but returns serialized form by default.
-        """
-
-        p = super(HttpPool, self).schematicLoadProduct(resourcetype=resourcetype,
-                                                       index=index,
-                                                       serialized=serialized
-                                                       )
-        return p
