@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import immutabledict
 import datetime
 import fractions
 import decimal
@@ -169,7 +168,7 @@ def test_serialization():
                 setattr(self, k, v)
 
     v = [
-        #arange(0, 10, 1, dtype=int).reshape((2, 5)),
+        # arange(0, 10, 1, dtype=int).reshape((2, 5)),
         datetime.datetime(year=2017, month=1, day=19,
                           hour=23, minute=00, second=00),
         1 + 2j,
@@ -186,6 +185,7 @@ def test_sys():
     assert sys.int_info.sizeof_digit == 4
     assert sys.float_info.dig == 15
     assert sys.maxsize == 2**63 - 1
+    assert sys.hash_info.width == 64
 
 
 def est_TupleKeys():
@@ -448,6 +448,7 @@ def test_datatypes():
     a1 = -1
     v2 = Quaternion([a1, 1+0, 1-a1+0.3, 4.5])
     assert v == v2
+    checkjson(v)
 
 
 def test_Parameter_init():
@@ -654,6 +655,20 @@ def test_Parameter_features():
     else:  # smart
         v = Parameter(a2, a1, a4)
         assert v.value == 9
+    # with known types this is ok
+    a2 = [2.2, 3.3, 1.1, 0]
+    a4 = 'quaternion'
+    v = Parameter(a2, a1, a4)
+    assert v.value == [2.2, 3.3, 1.1, 0]
+    assert issubclass(v.value.__class__, list)
+    v = NumericParameter(typ_='vector')
+    v.value = [1, 2, 3]
+    assert v.value == Vector([1, 2, 3])
+    # ok for NumericParameter w/o explicite type
+    v = NumericParameter()
+    # with pytest.raises(TypeError):
+    v.value = [9, 4, 1]
+
     # type not Number nor in DataTypes gets NotImplementedError
     a2 = 9
     a4 = 'guess'
@@ -724,6 +739,16 @@ def test_Parameter_features():
     v.value = b2
     checkjson(v)
 
+    a2 = [2.2, 3.3, 1.1, 0]
+    a4 = 'quaternion'
+    v = Parameter(a2, 'foo', a4)
+    # serializing special types will fail
+    with pytest.raises(TypeError):
+        checkjson(v)
+    v = Parameter()
+    v.type = a4
+    v.value = a2
+
     # event
     global test123
     test = None
@@ -924,27 +949,27 @@ def test_StringParameter():
 
 def test_MetaData():
     # creation
-    a1 = 'age'
-    a2 = NumericParameter(description='since 2000',
+    a1='age'
+    a2=NumericParameter(description='since 2000',
                           value=20, unit='year', typ_='integer')
-    v = MetaData()
+    v=MetaData()
     v.set(a1, a2)
     assert v.get(a1) == a2
     # add more parameter
-    a3 = 'Bob'
+    a3='Bob'
     v.set(name='name', newParameter=Parameter(a3))
     assert v.get('name').value == a3
 
     # access parameters in metadata
-    v = MetaData()
+    v=MetaData()
     # a more readable way to set a parameter
-    v[a1] = a2  # DRM doc case
+    v[a1]=a2  # DRM doc case
     # a more readable way to get a parameter
     assert v[a1] == a2
     assert v.get(a1) == a2
-    v['time'] = NumericParameter(description='another param',
+    v['time']=NumericParameter(description='another param',
                                  value=2.3, unit='sec')
-    v['birthday'] = Parameter(description='was made on',
+    v['birthday']=Parameter(description='was made on',
                               value=FineTime('2020-09-09T12:34:56.789098 UTC'))
     # names of all parameters
     assert [n for n in v] == [a1, 'time', 'birthday']
@@ -955,27 +980,27 @@ def test_MetaData():
     assert v.size() == 2
 
     # copy
-    c = v.copy()
+    c=v.copy()
     assert c is not v
     assert v.equals(c)
     assert c.equals(v)
 
     # equality
-    a1 = 'foo'
-    a2 = Parameter(description='test param', value=534)
-    a3 = 'more'
-    a4 = NumericParameter(description='another param',
+    a1='foo'
+    a2=Parameter(description='test param', value=534)
+    a3='more'
+    a4=NumericParameter(description='another param',
                           value=2.3, unit='sec')
-    v = MetaData()
-    v[a1] = a2
-    v[a3] = a4
-    b1 = ''.join(a1)
-    b2 = a2.copy()
-    b3 = ''.join(a3)
-    b4 = a4.copy()
-    v1 = MetaData()
-    v1[b1] = b2
-    v1[b3] = b4
+    v=MetaData()
+    v[a1]=a2
+    v[a3]=a4
+    b1=''.join(a1)
+    b2=a2.copy()
+    b3=''.join(a3)
+    b4=a4.copy()
+    v1=MetaData()
+    v1[b1]=b2
+    v1[b3]=b4
     assert v == v1
     assert v1 == v
     v1[b3].value += 3
